@@ -1,8 +1,9 @@
 from __future__ import annotations
 
-from functools import cached_property
 from typing import TYPE_CHECKING
 
+from backports.cached_property import cached_property
+
 from neoscore.core.brush import Brush
 from neoscore.core.color import Color
 from neoscore.core.directions import DirectionX
